@@ -32,7 +32,7 @@ import adafruit_bus_device.i2c_device as i2c_device
 from micropython import const
 
 
-__version__ = "1.1.0"
+__version__ = "1.2.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_SCD4X.git"
 
 SCD4X_DEFAULT_ADDR = 0x62
@@ -43,6 +43,7 @@ _SCD4X_SELFTEST = const(0x3639)
 _SCD4X_DATAREADY = const(0xE4B8)
 _SCD4X_STOPPERIODICMEASUREMENT = const(0x3F86)
 _SCD4X_STARTPERIODICMEASUREMENT = const(0x21B1)
+_SCD4X_STARTLOWPOWERPERIODICMEASUREMENT = const(0x21AC)
 _SCD4X_READMEASUREMENT = const(0xEC05)
 _SCD4X_SERIALNUMBER = const(0x3682)
 _SCD4X_GETTEMPOFFSET = const(0x2318)
@@ -229,7 +230,11 @@ class SCD4X:
 
     def start_periodic_measurement(self):
         """Put sensor into working mode, about 5s per measurement"""
-        self._send_command(_SCD4X_STARTPERIODICMEASUREMENT, cmd_delay=0.01)
+        self._send_command(_SCD4X_STARTPERIODICMEASUREMENT)
+
+    def start_low_periodic_measurement(self):
+        """Put sensor into low power working mode, about 30s per measurement"""
+        self._send_command(_SCD4X_STARTLOWPOWERPERIODICMEASUREMENT)
 
     def persist_settings(self):
         """Save temperature offset, altitude offset, and selfcal enable settings to EEPROM"""
